############
Installation
############

Python & OS Support
###################

terrarium is supported and tested with CPython versions 2.6 and 2.7.

terrarium is supported and tested with Linux and Windows.

Install using pip
#################

.. code-block:: shell-session

    $ pip install terrarium

Upgrade using pip
#################

.. code-block:: shell-session

    $ pip install -U terrarium

